@@ -27,9 +27,9 @@
 # HUBzero is a registered trademark of Purdue University.
 #
 
-source /etc/environ.sh
+. /etc/environ.sh
 
-if [[ -e ${HOME}/.environ ]]
+if [ -e ${HOME}/.environ ]
 then
   for e in $(sed 's,[[:space:]]*#.*$,,' ${HOME}/.environ)
   do
